#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.8.4
id: tasty-quickcheck-0.8.4-be8b412a2fbf5b37aca9e2070c9110c1
key: tasty_8YGWsrHIQGJDHLyJ2382ks
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-quickcheck-0.8.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-quickcheck-0.8.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-quickcheck-0.8.4
hs-libraries: HStasty-quickcheck-0.8.4-8YGWsrHIQGJDHLyJ2382ks
depends:
    QuickCheck-2.8.2-7d8390b8c258848854e348a0ea775aaf
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    tasty-0.11.0.2-6ecf5c4c4584053c63756484aea2d9b8
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
